summaryrefslogtreecommitdiffstats
path: root/kplato/kptrelation.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptrelation.h')
-rw-r--r--kplato/kptrelation.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kplato/kptrelation.h b/kplato/kptrelation.h
index 2ae6032d..35c2869a 100644
--- a/kplato/kptrelation.h
+++ b/kplato/kptrelation.h
@@ -23,10 +23,10 @@
#include "kptduration.h"
-#include <qstring.h>
+#include <tqstring.h>
-class QCanvas;
-class QDomElement;
+class TQCanvas;
+class TQDomElement;
namespace KPlato
{
@@ -46,13 +46,13 @@ class Relation {
public:
enum Type { FinishStart, FinishFinish, StartStart };
- Relation(Node *parent, Node *child, Type type, Duration lag);
- Relation(Node *parent=0, Node *child=0, Type type=FinishStart);
+ Relation(Node *tqparent, Node *child, Type type, Duration lag);
+ Relation(Node *tqparent=0, Node *child=0, Type type=FinishStart);
Relation(Relation *rel);
/**
* When deleted the relation will remove itself from
* the parent- and child nodes lists
*/
virtual ~Relation();
@@ -60,16 +60,16 @@ public:
Type type() const { return m_type; }
/** returns the lag.
* The lag of a relation is the time it takes between the parent starting/stopping
* and the start of the child.
*/
const Duration &lag() const { return m_lag; }
void setLag(Duration lag) { m_lag = lag; }
/**
* @return The parent dependent node.
*/
- Node *parent() const { return m_parent; }
+ Node *tqparent() const { return m_parent; }
/**
* @return The child dependent node.
*/
@@ -81,8 +81,8 @@ public:
NOTIMPL = 2l
};
- bool load(QDomElement &element, Project &project);
- void save(QDomElement &element) const;
+ bool load(TQDomElement &element, Project &project);
+ void save(TQDomElement &element) const;
protected: // variables
Node *m_parent;
@@ -91,11 +91,11 @@ protected: // variables
Duration m_lag;
private:
- QString m_parentId;
+ TQString m_parentId;
#ifndef NDEBUG
public:
- void printDebug(QCString indent);
+ void printDebug(TQCString indent);
#endif
};
@@ -103,8 +103,8 @@ public:
class ProxyRelation : public Relation
{
public:
- ProxyRelation(Node *parent, Node *child, Relation::Type type, Duration lag)
- : Relation(parent, child, type, lag)
+ ProxyRelation(Node *tqparent, Node *child, Relation::Type type, Duration lag)
+ : Relation(tqparent, child, type, lag)
{}
~ProxyRelation() { m_parent = 0; m_child = 0;}
@@ -46,13 +46,13 @@ class Relation {
/**
* When deleted the relation will remove itself from
- * the parent- and child nodes lists
+ * the tqparent- and child nodes lists
*/
virtual ~Relation();
@@ -60,16 +60,16 @@ public:
Type type() const { return m_type; }
/** returns the lag.
- * The lag of a relation is the time it takes between the parent starting/stopping
+ * The lag of a relation is the time it takes between the tqparent starting/stopping
* and the start of the child.
*/
@@ -60,16 +60,16 @@ public:
void setLag(Duration lag) { m_lag = lag; }
/**
- * @return The parent dependent node.
+ * @return The tqparent dependent node.
*/